@@ -27,52 +27,51 @@
 
 namespace bt
 {
-    class TorrentInterface;
+class TorrentInterface;
 }
 
 namespace kt
 {
 
+/**
+    Dialog to show when files are missing.
+*/
+class MissingFilesDlg : public QDialog, public Ui_MissingFilesDlg
+{
+    Q_OBJECT
+public:
+
     /**
-        Dialog to show when files are missing.
-    */
-    class MissingFilesDlg : public QDialog, public Ui_MissingFilesDlg
-    {
-        Q_OBJECT
-    public:
+     * Constructor
+     * @param text Text to show above file list
+     * @param missing The list of missing files
+     * @param tc The torrent
+     * @param parent The parent widget
+     */
+    MissingFilesDlg(const QString& text, const QStringList& missing, bt::TorrentInterface* tc, QWidget* parent);
+    ~MissingFilesDlg() override;
 
-        /**
-         * Constructor
-         * @param text Text to show above file list
-         * @param missing The list of missing files
-         * @param tc The torrent
-         * @param parent The parent widget
-         */
-        MissingFilesDlg(const QString& text, const QStringList& missing, bt::TorrentInterface* tc, QWidget* parent);
-        ~MissingFilesDlg() override;
-
-        enum ReturnCode
-        {
-            RECREATE, DO_NOT_DOWNLOAD, CANCEL, NEW_LOCATION_SELECTED
-        };
-
-        /**
-         * Execute the dialog
-         * @return What to do
-         */
-        ReturnCode execute();
-
-    private slots:
-        void dndPressed();
-        void recreatePressed();
-        void cancelPressed();
-        void selectNewPressed();
-
-    private:
-        ReturnCode ret;
-        bt::TorrentInterface* tc;
+    enum ReturnCode {
+        RECREATE, DO_NOT_DOWNLOAD, CANCEL, NEW_LOCATION_SELECTED
     };
 
+    /**
+     * Execute the dialog
+     * @return What to do
+     */
+    ReturnCode execute();
+
+private Q_SLOTS:
+    void dndPressed();
+    void recreatePressed();
+    void cancelPressed();
+    void selectNewPressed();
+
+private:
+    ReturnCode ret;
+    bt::TorrentInterface* tc;
+};
+
 }
 
 #endif
