@@ -31,40 +31,42 @@ class QMenu;
 
 namespace kt
 {
-    class MagnetManager;
-    class MagnetModel;
+class MagnetManager;
+class MagnetModel;
 
-    /**
-        View which displays a list of magnet links being downloaded
-    */
-    class MagnetView : public QWidget
-    {
-        Q_OBJECT
-    public:
-        MagnetView(MagnetManager* magnetManager, QWidget* parent = 0);
-        ~MagnetView() override;
+/**
+    View which displays a list of magnet links being downloaded
+*/
+class MagnetView : public QWidget
+{
+    Q_OBJECT
+public:
+    MagnetView(MagnetManager* magnetManager, QWidget* parent = 0);
+    ~MagnetView() override;
 
-        void saveState(KSharedConfigPtr cfg);
-        void loadState(KSharedConfigPtr cfg);
+    void saveState(KSharedConfigPtr cfg);
+    void loadState(KSharedConfigPtr cfg);
 
-        void keyPressEvent(QKeyEvent* event) override;
+    void keyPressEvent(QKeyEvent* event) override;
 
-    private slots:
-        void showContextMenu(QPoint p);
-        void removeMagnetDownload();
-        void startMagnetDownload();
-        void stopMagnetDownload();
+private Q_SLOTS:
+    void showContextMenu(QPoint p);
+    void removeMagnetDownload();
+    void startMagnetDownload();
+    void stopMagnetDownload();
+    void copyMagnetUrl();
 
-    private:
-        MagnetManager* mman;
-        MagnetModel* model;
-        QTreeView* view;
-        QMenu* menu;
+private:
+    MagnetManager* mman;
+    MagnetModel* model;
+    QTreeView* view;
+    QMenu* menu;
 
-        QAction* start;
-        QAction* stop;
-        QAction* remove;
-    };
+    QAction* start;
+    QAction* stop;
+    QAction* copy_url;
+    QAction* remove;
+};
 
 }
 
