@@ -27,39 +27,39 @@
 
 namespace kt
 {
-    struct ScheduleItem;
-    class Schedule;
+struct ScheduleItem;
+class Schedule;
+
+/**
+    @author
+*/
+class EditItemDlg : public QDialog, public Ui_EditItemDlg
+{
+    Q_OBJECT
+public:
+    EditItemDlg(Schedule* schedule, ScheduleItem* item, bool new_item, QWidget* parent);
+    ~EditItemDlg() override;
 
     /**
-        @author
-    */
-    class EditItemDlg : public QDialog, public Ui_EditItemDlg
-    {
-        Q_OBJECT
-    public:
-        EditItemDlg(Schedule* schedule, ScheduleItem* item, bool new_item, QWidget* parent);
-        ~EditItemDlg() override;
+     * accept will only work if the item does not conflict
+     **/
+    void accept() override;
 
-        /**
-         * accept will only work if the item does not conflict
-         **/
-        void accept() override;
+private Q_SLOTS:
+    void fromChanged(const QTime& time);
+    void toChanged(const QTime& time);
+    void startDayChanged(int idx);
+    void endDayChanged(int idx);
+    void suspendedChanged(bool on);
+    void screensaverLimitsToggled(bool on);
 
-    private slots:
-        void fromChanged(const QTime& time);
-        void toChanged(const QTime& time);
-        void startDayChanged(int idx);
-        void endDayChanged(int idx);
-        void suspendedChanged(bool on);
-        void screensaverLimitsToggled(bool on);
+private:
+    void fillItem();
 
-    private:
-        void fillItem();
-
-    private:
-        Schedule* schedule;
-        ScheduleItem* item;
-    };
+private:
+    Schedule* schedule;
+    ScheduleItem* item;
+};
 
 }
 
